<?php
/**
 * @package     CSVI
 * @subpackage  Administrator
 *
 * @author      RolandD Cyber Produksi <contact@rolandd.com>
 * @copyright   Copyright (C) 2006 - @year@ RolandD Cyber Produksi. All rights reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link        https://rolandd.com
 */

use Joomla\CMS\Factory;
use Joomla\CMS\Filesystem\Path;
use Joomla\CMS\Form\Form;
use Joomla\CMS\Form\FormHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Uri\Uri;

defined('_JEXEC') or die;

if (!Factory::getUser()->authorise('core.manage', 'com_csvi'))
{
	throw new Exception(Text::_('JERROR_ALERTNOAUTHOR'), 404);
}

// Get the input object
$jinput = Factory::getApplication()->input;

// Define our version number
define('CSVI_VERSION', '@version@');

// Set CLI mode
define('CSVI_CLI', false);

// Setup the autoloader
JLoader::registerPrefix('Csvi', JPATH_ADMINISTRATOR . '/components/com_csvi');
JLoader::registerPrefix('Rantai', JPATH_ADMINISTRATOR . '/components/com_csvi/rantai');
JLoader::registerNamespace('Rocloud', JPATH_LIBRARIES . '/Rocloud/src', false, false, 'psr4');

if (file_exists(JPATH_ADMINISTRATOR . '/components/com_csvi/assets/google/vendor/autoload.php'))
{
	JLoader::import('google.vendor.autoload', JPATH_ADMINISTRATOR . '/components/com_csvi/assets');
}

require_once JPATH_ADMINISTRATOR . '/components/com_csvi/assets/vendor/autoload.php';

// All Joomla loaded, set our exception handler
require_once JPATH_BASE . '/components/com_csvi/rantai/error/exception.php';

// Load the helper class for the submenu
require_once JPATH_ADMINISTRATOR . '/components/com_csvi/helper/csvi.php';


// Set the folder path to the models
BaseDatabaseModel::addIncludePath(JPATH_ADMINISTRATOR . '/components/com_csvi/models');

// Get the database object
$db = Factory::getDbo();

// Define the tmp folder
$config = Factory::getConfig();

if (!defined('CSVIPATH_TMP'))
{
	$tmpPath = $config->get('tmp_path');

	if (!is_dir($tmpPath))
	{
		$tmpPath = JPath::clean(JPATH_SITE . '/tmp', '/');
	}

	define('CSVIPATH_TMP', $tmpPath . '/com_csvi');
}

if (!defined('CSVIPATH_DEBUG'))
{
	$logPath = $config->get('log_path');

	if (!is_dir($logPath))
	{
		$logPath = Path::clean(JPATH_SITE . '/logs', '/');
	}

	define('CSVIPATH_DEBUG', $logPath);
}

// Set the global settings
$csvisettings = new CsviHelperSettings($db);

// Load jQuery framework because csvi.js depends on it. The rest is loaded by the Joomla template.
HTMLHelper::_('jquery.framework');

$document = Factory::getDocument();
$document->addStyleSheet(Uri::root() . 'administrator/components/com_csvi/assets/css/display.css', ['version' => 'auto']);
$document->addStyleSheet(Uri::root() . 'administrator/components/com_csvi/assets/css/dropzone.css', ['version' => 'auto']);
$document->addScript(Uri::root() . 'administrator/components/com_csvi/assets/js/dropzone.js', ['version' => 'auto']);
$document->addScript(Uri::root() . 'administrator/components/com_csvi/assets/js/csvi.js', ['version' => 'auto']);

Form::addFieldPath(JPATH_ADMINISTRATOR . '/components/com_csvi/models/fields');

// Add language strings to JavaScript
// General
Text::script('COM_CSVI_ERROR');
Text::script('COM_CSVI_ERROR_500');
Text::script('COM_CSVI_INFORMATION');
Text::script('COM_CSVI_CLOSE_DIALOG');
Text::script('COM_CSVI_NO_CLIENT_ID_AND_SECRET');

// Template wizard
Text::script('COM_CSVI_FILEHEADER');
Text::script('COM_CSVI_TEMPLATEHEADER');
Text::script('COM_CSVI_ERROR_NO_CONNECTION');

// About view
Text::script('COM_CSVI_ERROR_CREATING_FOLDER');
Text::script('COM_ROCSVI_RANTAI_AVAILABLE');
Text::script('COM_ROCSVI_RANTAI_NOT_AVAILABLE');

// Process
Text::script('COM_CSVI_ERROR_DURING_PROCESS');
Text::script('COM_CSVI_CHOOSE_TEMPLATE_FIELD');

// Maintenance
Text::script('COM_CSVI_ERROR_PROCESSING_RECORDS');

try
{
	// Load the defaults
	require_once JPATH_ADMINISTRATOR . '/components/com_csvi/helper/autoloader.php';
	require_once JPATH_ADMINISTRATOR . '/components/com_csvi/controllers/default.php';
	require_once JPATH_ADMINISTRATOR . '/components/com_csvi/models/default.php';
	require_once JPATH_ADMINISTRATOR . '/components/com_csvi/tables/default.php';

	// Add the path of the form location
	FormHelper::addFormPath(JPATH_ADMINISTRATOR . '/components/com_csvi/models/forms/');
	FormHelper::addFieldPath(JPATH_ADMINISTRATOR . '/components/com_csvi/models/fields/');

	$controller = BaseController::getInstance('csvi');
	$controller->execute($jinput->get('task'));
	$controller->redirect();

	if (empty($format))
	{
		?>
        <div class="span10 center">
            <a href="https://rolandd.com/" target="_blank">RO CSVI</a> @version@ | Copyright (C) 2006 - @year@
            <a href="https://rolandd.com/" target="_blank">RolandD Cyber Produksi</a>
        </div>
        <?php
	}
}
catch (Exception $e)
{
	$oldUrl = Uri::getInstance($_SERVER['HTTP_REFERER']);
	Factory::getApplication()->redirect('index.php?option=com_csvi&view=' . $oldUrl->getVar('view', 'templates'), $e->getMessage(), 'error');
}
